@@ -41,7 +41,8 @@ def read_structure(filename):
     elif lower_filename.startswith("poscar") \
             or lower_filename.startswith("contcar"):
         return Poscar.from_file(filename, False).structure
-    elif lower_filename.startswith("chgcar"):
+    elif lower_filename.startswith("chgcar") \
+            or lower_filename.startswith("locpot"):
         return Chgcar.from_file(filename).structure
     elif re.search("vasprun", lower_filename) \
             and re.search("xml", lower_filename):
