@@ -170,6 +170,52 @@ def pbc_all_distances(lattice, fcoords1, fcoords2):
 
     return distances
 
+def pbc_shortest_vectors(lattice, fcoords1, fcoords2):
+    """
+    Returns the shortest vectors between two lists of coordinates taking into
+    account periodic boundary conditions and the lattice.
+
+    Args:
+        lattice:
+            lattice to use
+        fcoords1:
+            First set of fractional coordinates. e.g., [0.5, 0.6,
+            0.7] or [[1.1, 1.2, 4.3], [0.5, 0.6, 0.7]]. It can be a single
+            coord or any array of coords.
+        fcoords2:
+            Second set of fractional coordinates.
+
+    Returns:
+        array of displacement vectors
+    """
+    #ensure correct shape
+    fcoords1, fcoords2 = np.atleast_2d(fcoords1, fcoords2)
+
+    #ensure that all points are in the unit cell
+    fcoords1 = np.mod(fcoords1, 1)
+    fcoords2 = np.mod(fcoords2, 1)
+
+    #create images, 2d array of all length 3 combinations of [-1,0,1]
+    r = np.arange(-1, 2)
+    arange = r[:, None] * np.array([1, 0, 0])[None, :]
+    brange = r[:, None] * np.array([0, 1, 0])[None, :]
+    crange = r[:, None] * np.array([0, 0, 1])[None, :]
+    images = arange[:, None, None] + brange[None, :, None] + \
+        crange[None, None, :]
+    images = images.reshape((27, 3))
+
+    #create images of f2
+    shifted_f2 = fcoords2[:, None, :] + images[None, :, :]
+
+    cart_f1 = lattice.get_cartesian_coords(fcoords1)
+    cart_f2 = lattice.get_cartesian_coords(shifted_f2)
+
+    #all vectors from f1 to f2
+    vectors = cart_f2[None, :, :, :] - cart_f1[:, None, None, :]
+
+    d_2 = np.sum(vectors ** 2, axis=3)
+    a, b = np.indices([len(fcoords1), len(fcoords1)])
+    return vectors[a, b, np.argmin(d_2, axis=2)]
 
 def find_in_coord_list_pbc(fcoord_list, fcoord, atol=1e-8):
     """
