@@ -27,7 +27,7 @@ def generate_latex_table(results, header=None, caption=None, label=None):
         String representation of Latex table with data.
     """
     body = []
-    if header != None:
+    if header is not None:
         body.append(" & ".join(header) + "\\\\")
         body.append("\\hline")
     maxlength = 0
@@ -35,18 +35,12 @@ def generate_latex_table(results, header=None, caption=None, label=None):
         maxlength = max(maxlength, len(result))
         body.append(" & ".join([str(m) for m in result]) + "\\\\")
     colstr = "c" * maxlength
-    output = []
-    output.append("\\begin{table}[H]")
-    output.append("\\caption{{{}}}".format(caption if caption else
-                                           "Caption"))
-    output.append("\\label{{{}}}".format(label if label else "Label"))
-    output.append("\\begin{tabular*}{\\textwidth}{@{\\extracolsep{\\fill}}" +
-                  colstr + "}")
-    output.append("\\hline")
-    output.append("\n".join(body))
-    output.append("\\hline")
-    output.append("\\end{tabular*}")
-    output.append("\\end{table}")
+    output = ["\\begin{table}[H]",
+              "\\caption{{{}}}".format(caption if caption else
+              "Caption"), "\\label{{{}}}".format(label if label else "Label"),
+              "\\begin{tabular*}{\\textwidth}{@{\\extracolsep{\\fill}}" +
+              colstr + "}", "\\hline", "\n".join(body), "\\hline",
+              "\\end{tabular*}", "\\end{table}"]
     return "\n".join(output)
 
 
@@ -67,7 +61,7 @@ def str_delimited(results, header=None, delimiter="\t"):
         Aligned string output in a table-like format.
     """
     returnstr = ""
-    if header != None:
+    if header is not None:
         returnstr += delimiter.join(header) + "\n"
     return returnstr + "\n".join([delimiter.join([str(m) for m in result])
                                   for result in results])
@@ -94,13 +88,13 @@ def str_aligned(results, header=None):
     count = 0
     for i in k:
         col_max_len = max([len(str(m)) for m in i])
-        if header != None:
+        if header is not None:
             col_max_len = max([len(str(header[count])), col_max_len])
         stringlengths.append(col_max_len)
         count += 1
     format_string = "   ".join(["%" + str(d) + "s" for d in stringlengths])
     returnstr = ""
-    if header != None:
+    if header is not None:
         header_str = format_string % tuple(header)
         returnstr += header_str + "\n"
         returnstr += "-" * len(header_str) + "\n"
@@ -144,7 +138,7 @@ def latexify(formula):
     Returns:
         Formula suitable for display as in LaTeX with proper subscripts.
     """
-    return re.sub(r"(\d+)", r"$_{\1}$", formula)
+    return re.sub(r"([A-Za-z\(\)])(\d+)", r"\1$_{\2}$", formula)
 
 
 def latexify_spacegroup(spacegroup_symbol):
